Description: A South Park minden idők egyik legismertebb animációs sorozata, 4 mocskos szájú negyedikesről, amely szürreális humorával űz gúnyt világunkból.

Összes

- Összes
- Személy
- Film
- Színdarab
- Tv műsor
- Esemény
- Csoport
- Helyszín
- TV csatorna
- Cikk

- Filmek estére
- Mozi
  - Moziműsor
  - Mozi premierek
- Színház
  - Színházműsor
  - Színházi bemutatók
- Hétvége
  - Hétvége
  - Gyerek hétvége
- Kritikák
- Trailerek
- Top 100 film
- Összes
  - Filmek estére
  - Moziműsor
  - Mozi premierek
  - Színházműsor
  - Színházi bemutatók
  - Hétvége
  - Gyerek hétvége
  - Kritikák
  - Trailerek
  - Top 100 film

- Filmek estére
- Moziműsor
- Mozi premierek
- Színházműsor
- Színházi bemutatók
- Hétvége
- Gyerek hétvége
- Kritikák
- Trailerek
- Top 100 film

Programkereső

- Ma
  - Ma
  - Holnap
  - A héten
  - Hétvégén
  - Bármikor
- Budapest
  - Országos
  - Ajka
  - Békéscsaba
  - Bölcske
  - Budaörs
  - Budapest
  - Bük (Bükfürdő)
  - Cegléd
  - Debrecen
  - Dunaújváros
  - Eger
  - Gödöllő
  - Gyenesdiás
  - Gyöngyös
  - Győr
  - Gyula
  - Hévíz
  - Hódmezővásárhely
  - Kaposvár
  - Kecskemét
  - Keszthely
  - Kisújszállás
  - Kisvárda
  - Martfű
  - Miskolc
  - Nagykanizsa
  - Nagykőrös
  - Nyíregyháza
  - Pécs
  - Salgótarján
  - Siófok
  - Sopron
  - Szeged
  - Székesfehérvár
  - Szekszárd
  - Szentendre
  - Szentes
  - Szigetszentmiklós
  - Szolnok
  - Szombathely
  - Tatabánya
  - Vác
  - Veszprém
  - Zalaegerszeg
- Mozi
  - TV
  - Mozi
  - Színház
  - Koncert
  - Fesztivál
  - Kiállítás
  - Könyv
  - Egyéb

# South Park / Gluténmentes ebola

Bakancslistához adom
amerikai animációs sorozat, XVIII / 2. rész, 23 perc

## Értékelés:

1450 szavazatból
Szerinted?

1857 hozzászólás

Az aktuális rész ismertetője: South Park gluténmentessé válik.

A műsor ismertetése: A South Park minden idők egyik legismertebb animációs sorozata, 4 mocskos szájú negyedikesről, amely szürreális humorával űz gúnyt világunkból.

## Évadok:

- 1
- 2
- 3
- 4
- 5
- 6
- 7
- 8
- 9
- 10
- 11
- 12
- 13
- 14
- 15
- 16
- 17
- 18
- 19
- 20
- 21
- 22
- 23
- 24
- 25
- 26

## Stáblista:

### Szereplők

Trey Parker Matt Stone Mary Kay Bergman Isaac Hayes Eliza Schneider

### Alkotók

- rendező: Trey Parker Matt Stone Eric Stough
- zene: Scott Nickoley Jamie Dunlap
- executive producer: Anne Garefino Brian Graden Deborah Liebling Trey Parker Matt Stone
- vágó: Brandon Cruz Gian Ganziano David List

Stáblista mutatása

## Kapcsolódó cikkek:

### A leggázabb poénkodások a South Parkban

Trey Parker, a South Park-os csávók egyik fele október 19-én ünnepelte a szülinapját. Miközben a...

2022. október 23. PORT.hu

### „Itt jövök, Staaaaaaan!” – amikor a South Park Stephen Kinget idézte

Még emlékszünk azokra az időkre, amikor az iskolaköpeny és a körmös nosztalgiájában élő irodalomtanárnők vörös...

2022. június 20. Kirsch András

### A South Park szereplői már az atomháborúra készülnek

Erősen indul a 25. évad.

2022. március 2. PORT.hu

### Új streamingszolgáltató Magyarországon – ez lesz a programban

A Paramount+ hozzánk is megérkezik még idén SkyShowtime néven.

2022. február 18. PORT.hu

### A filmtörténelem leggyilkosabb szatírái

15 éve, 2006. november 3-án volt a Borat című kiváló szatíra amerikai premierje. Ebből az...

2021. november 6. PORT.hu

### Tonnányi South Park érkezik a jövőben

A 30. évadig biztosan fut a sorozat, és 14 egészestés filmet is láthatunk majd.

2021. augusztus 6. PORT.hu

### 10 sorozatepizód, amelyet a bemutató után azonnal be is tiltottak

Az talán nem olyan meglepő, hogy az X-akták egyik epizódja kiverte a biztosítékot, de így...

2021. június 27. PORT.hu

### Íme az 5 legjobb South Park-epizód!

Május 26-án lett ötvenéves Matt Stone, aki Trey Parker mellett a szabad szájú animációs sorozat...

2021. május 26. PORT.hu

### 9 kihagyhatatlan animációs sorozat a Netflixen, csak felnőtteknek

Inkorrekt komédiák, agyament sci-fik, életre kelt hormonszörnyek és vérben tocsogó szuperhősök.

2021. május 23. PORT.hu

### 8 dolog, amit a South Park előre megjósolt

A Pokémon Go sikere és Oszama bin Laden likvidálása után a jövőbe látó South Park-stáb...

2021. március 5. Szűcs Gyula

### Már South Parkba is megérkezett a vakcina

Új különkiadással jelentkezik a rajzfilmsorozat.

2021. március 4. PORT.hu

### Fogvatartói állítólag ezt a filmet nézették Szaddam Husszeinnel

A South Park: Nagyobb, hosszabb és vágatlan hozza az animációs filmekben valaha elhangzott legtöbb káromkodás...

2020. november 20. Vízer Balázs

### South Parkot is elérte a koronavírus

Október 5-én este a magyar Comedy Central is leadja a népszerű animációs sorozatnak a koronavírus-járvány...

2020. október 5. PORT.hu

### Ezeket a South Park epizódokat daráld a koronavírus ideje alatt, ha jót akarsz – és ha rosszat

A szabad szájú animációs széria alkotói kiválasztották nekünk a legjobb és legrosszabb részeket.

2020. április 20. PORT.hu

### A Cartman karakterét inspiráló férfi orvosi kezelésére gyűjtenek pénzt a South Park alkotói

A szomorú apropó ugyanakkor jó alkalom arra, hogy megismerjük a sztorit, honnan ered mindenki kedvenc...

2019. december 5. PORT.hu

### Több mint 500 millió dollárért vették meg a South Parkot

Félmilliárd dollárnál is többet fizetett az HBO streamelős szolgáltatása a felnőtteknek szóló népszerű animációs széria...

2019. október 30. PORT.hu

### A South Park rendezőpárosa újabb mozifilmre készül

Miközben bejelentették, hogy újabb három évaddal meghosszabbítják népszerű animációs sorozatukat, Matt Stone-nak és Trey Parkernek...

2019. szeptember 13. PORT.hu

### 5 kiváló animációs film, amiben Jézus is szerepel!

A Simpson család mellett a Family Guyban, a South Parkban és Jankovics Marcell soha el...

2019. április 20. Szűcs Gyula

### Híres filmek és rajzfilmek korai változatai

A Szemtől szemben Michael Mann saját tévéfilmjének remake-je, a South Park eredetileg karácsonyi üdvözlet volt.

2018. június 13. Lakatos István

### 10 színész, aki saját maga kérte, hogy öljék meg karakterét

Nem fenékig tejfel a sorozatszínészek élete. Erre szép példa a cikkben szereplő tíz színész története,...

2017. március 10. PORT.hu

### Csodás videó, ahogy a South Park alkotója a lányával szinkronizál

Az új évadban Trey Parker lánya a Kanadából szalajtott Ike Broflovski hangja.

2016. november 17. PORT.hu

### Így alakította át a South Park a tévés cenzúrát

Ami a South Park indulásakor még elképzelhetetlen volt a tévében, mára többek között ennek a...

2016. november 4. Marczisovszky Márton

### Hírünk a nagyvilágban: magyar dokival poénkodik a South Park!

A University of Hungary orvosa gyilkos szóviccel trollkodik egy melleltávolító műtéten átesett nőn.

2016. szeptember 29. PORT.hu

### Így változott a South Park főcíme az elmúlt 20 évadban

Elkezdődött a South Park jubileumi évada, nézzük át, honnan hova jutott a sorozat!

2016. szeptember 22. Marczisovszky Márton

### Pc vs South Park - 19. évad

A legtöbb sorozat színvonala az évadok múlásával egyre romlik, Trey Parkerék közel két évtizede futó...

2016. március 28. Csiger Ádám
További cikkek mutatása

- Megosztom Facebookon

Szerkeszd te is a Port.hu-t!

#### Ha hiányosságot találsz, vagy valamihez van valamilyen érdekes hozzászólásod, írd meg nekünk!

Küldés

Figyelem: A beküldött észrevételeket a szerkesztőink értékelik, csak azok a javasolt változtatások valósulhatnak meg, amik jóváhagyást kapnak. Kérjük, forrásmegjelöléssel támaszd alá a leírtakat!

## Játszási időpontok

február 11. - szombat

- 00:25 Comedy Central XVIII / 5. rész

- 05:25 Comedy Central XVIII / 5. rész

február 12. - vasárnap

- 00:25 Comedy Central XVI / 11. rész

- 00:55 Comedy Central XVI / 12. rész

- 01:25 Comedy Central XVI / 13. rész

- 01:55 Comedy Central XVI / 14. rész

- 02:25 Comedy Central XVIII / 1. rész

február 13. - hétfő

- 00:25 Comedy Central XVIII / 2. rész

- 00:55 Comedy Central XVIII / 3. rész

- 01:25 Comedy Central XVIII / 4. rész

- 01:55 Comedy Central XVIII / 5. rész

- 23:55 Comedy Central XVIII / 6. rész

február 14. - kedd

- 00:25 Comedy Central XVIII / 7. rész

- 04:55 Comedy Central XVIII / 6. rész

- 05:25 Comedy Central XVIII / 7. rész

- 23:55 Comedy Central XVIII / 8. rész

február 15. - szerda

- 00:25 Comedy Central XVIII / 9. rész

- 04:55 Comedy Central XVIII / 8. rész

- 05:25 Comedy Central XVIII / 9. rész

- 23:55 Comedy Central XVIII / 10. rész

február 16. - csütörtök

- 00:25 Comedy Central XIX / 1. rész

- 04:55 Comedy Central XVIII / 10. rész

- 05:25 Comedy Central XIX / 1. rész

- 23:55 Comedy Central XIX / 2. rész

február 17. - péntek

- 00:25 Comedy Central XIX / 3. rész

- 04:55 Comedy Central XIX / 2. rész

- 05:25 Comedy Central XIX / 3. rész

- 23:55 Comedy Central XIX / 4. rész

február 18. - szombat

- 00:25 Comedy Central XIX / 5. rész

- 04:55 Comedy Central XIX / 4. rész

- 05:25 Comedy Central XIX / 5. rész

február 19. - vasárnap

- 00:25 Comedy Central XVIII / 6. rész

- 00:55 Comedy Central XVIII / 7. rész

- 01:25 Comedy Central XVIII / 8. rész

- 01:55 Comedy Central XVIII / 9. rész

- 02:25 Comedy Central XVIII / 10. rész

február 20. - hétfő

- 00:25 Comedy Central XIX / 1. rész

- 00:55 Comedy Central XIX / 2. rész

- 01:25 Comedy Central XIX / 3. rész

- 01:55 Comedy Central XIX / 4. rész

- 02:25 Comedy Central XIX / 5. rész

- 23:55 Comedy Central XIX / 5. rész

február 21. - kedd

- 00:25 Comedy Central XIX / 6. rész

- 04:55 Comedy Central XIX / 5. rész

- 05:25 Comedy Central XIX / 6. rész

- 23:55 Comedy Central XXVI / 2. rész

február 22. - szerda

- 00:25 Comedy Central XIX / 7. rész

- 04:55 Comedy Central XXVI / 2. rész

- 05:25 Comedy Central XIX / 7. rész

- 23:55 Comedy Central XIX / 8. rész

február 23. - csütörtök

- 00:25 Comedy Central XIX / 9. rész

- 04:55 Comedy Central XIX / 8. rész

- 05:25 Comedy Central XIX / 9. rész

- 23:55 Comedy Central XIX / 10. rész

február 24. - péntek

- 00:25 Comedy Central XXI / 1. rész

- 04:55 Comedy Central XIX / 10. rész

- 05:25 Comedy Central XXI / 1. rész

Comedy Central
február 11. - szombat XXI / 1. rész

- 00:25
- 05:25

február 12. - vasárnap XXI / 1. rész

- 00:25
- 00:55
- 01:25
- 01:55
- 02:25

február 13. - hétfő XXI / 1. rész

- 00:25
- 00:55
- 01:25
- 01:55
- 23:55

február 14. - kedd XXI / 1. rész

- 00:25
- 04:55
- 05:25
- 23:55

február 15. - szerda XXI / 1. rész

- 00:25
- 04:55
- 05:25
- 23:55

február 16. - csütörtök XXI / 1. rész

- 00:25
- 04:55
- 05:25
- 23:55

február 17. - péntek XXI / 1. rész

- 00:25
- 04:55
- 05:25
- 23:55

február 18. - szombat XXI / 1. rész

- 00:25
- 04:55
- 05:25

február 19. - vasárnap XXI / 1. rész

- 00:25
- 00:55
- 01:25
- 01:55
- 02:25

február 20. - hétfő XXI / 1. rész

- 00:25
- 00:55
- 01:25
- 01:55
- 02:25
- 23:55

február 21. - kedd XXI / 1. rész

- 00:25
- 04:55
- 05:25
- 23:55

február 22. - szerda XXI / 1. rész

- 00:25
- 04:55
- 05:25
- 23:55

február 23. - csütörtök XXI / 1. rész

- 00:25
- 04:55
- 05:25
- 23:55

február 24. - péntek XXI / 1. rész

- 00:25
- 04:55
- 05:25

## Hozzászólások

Spoiler
Offtopik
Szerinted?

9/10
sawyerx 2022 okt. 31. - 15:51:39 9/10
Én Séf bácsi haláláig mondom azt, hogy kiváló minőséget képviselt a sorozat, utána a 15-16. évadig még egy-egy hasonló becsúszott, de az utána lévők már majdnem nézhetetlenek és nem viccesek.
Az egyik nagy kedvenc "a már nem olyan a minőség"-részek közül a pánsípos, ahol elpaterolják a pánsíposokat, de így előjönnek az óriás hörcsögök és megtámadják a városokat. Na ott van Craignek a repülőn és a barlangban egy olyan monológja, amit nálam a South Park egyik nagy mérföldköve :D
Válasz
9/10
Matyee33 2022 okt. 30. - 23:53:07 9/10 Előzmény Kit Fisto
A kanadai Terrance és Phillip nem létező sorozat csak a South Parkban látható néhány részben.
Válasz
Kit Fisto 2022 márc. 29. - 01:01:25
Mostanában nem valami jó. A comedy central mostanában nagyon ráhajtott a balos propagandára, a választás miatt. Állandóan a kifejezetten balosan politizáló "humoristáikat" futtatják, (pl. bödőcs) senki normálisat nem lehet látni és még a south Parkban is azok a részek mennek, amiben Garrison Donald Trumpot alakítja és persze Trumpot rossznak mutatják be. Magyar szál hiányában azt a jobboldali elnököt savazzák, aki jóban volt Orbánnal, a magyar jobboldali kormánnyal. Hol vannak már a kalandos, és vicces részek! A kedevenc részem a Netmentesen és a Gyűrűk ura videó, és a többi hasonló, nem politizáló és nem gyűlölködésről szóló kalandos, történetes részek. Pl. az is jó volt, amikor Cartman becsapta Butterst, hogy minden elpusztult, vagy amikor Butters káosz professzor volt, és Rettenet tábornok segítségével egy locsoló slagot megnyitva akarta eláraszatni a világot vízzel. Na és persze az első évad, annak nincs párja!
Válasz
Baluuu 2021 okt. 19. - 00:17:07
ezek a részek mosomedve 0....... és a folytatólagosak is,,, a régiek voltak az igaziak..... A poént is elbaszták a régi ek 10 böl 20 as ezek 10 böl 2
Válasz
9/10
sawyerx 2021 aug. 26. - 10:10:10 9/10 Előzmény gasparp
Az első 9-10 évad nagyon jó, ötletes részekkel és hangulattal, aztán ahogy a technika és grafika javul, úgy romlik a minőség. Régen epizodikus volt, a mostaniak már inkább évadon átívelő szálak, számomra béna poénokkal, és sok régi tök jó karaktert majdnem teljesen mellőznek. Az alkotók azt nyilatkozták, hogy pont a régi évadokra nem büszkék, pedig szerintem azok voltak kurva jók.
A másik hasonló sorozat a Family Guy, első 8 évad zseniális, ott is akkor jött a szintleadás, mikor a 4:3-as képarányról 16:9-es csilivi lett.
Az újakat nem követem, de nyilván sok embernek még bejön, mert van nézettség, sőt, South Parkból még egy csomó évadot és filmet berendeltek. Szóval szerintem érdemes mindkettőbe belevágni :D
Válasz
10/10
Marton12 2021 aug. 25. - 23:10:51 10/10 Előzmény gasparp
Nyugodtan elkezdheted, fantasztikus sorozat. Végig röhejes, ritkán kissé undorító, és végig megy a mocskos, de humoros káromkodás. Emellett a szinkron is szuper! Egyszerűen tökéletes az egész sorozat, úgy ahogy van. Megéri végignézni!
Válasz
gasparp 2021 ápr. 29. - 18:17:53
még nem kezdtem el de mondjatok már valamit mert nem akaraok valami erőltettett gagyiságba belekezdeni annak reményében hogy biztos jo.
Válasz
Kit Fisto 2021 ápr. 11. - 15:04:08 Előzmény nikato
Pedig ezek is jó részek. Bár nem tudom, miért figurázzák ki Kanadát. Majdnem olyan, mint az USA, én nem látok nagy különbséget. A Terrance és Phillip rajzfilmet is szívesen nézném, amit a fiúk szoktak nézni a tv-ben! A Brickleberrynél és az Archernél jobb lenne még az is ; )
Válasz
10/10
öregvidra 2021 febr. 27. - 12:51:24 10/10
Az első számú társadalomkritika...ilyet csak az Usában vagy Angliában lehet csinálni, más országokban lehetetlen lenne...
Válasz
8/10
nikato 2020 nov. 08. - 18:10:09 8/10
Sok tabu témát feszeget, politika, vallás, kultuszok, hátrányos helyzet, cenzúra. Kimeri mondani amit más nem. Az elmúlt hetekben néztem az évadokat sorban, most a 19-nél járok és nincs túlnyomóan sok káromkodás. Ha van is csak olyanok amiket használnak az emberek napi szinten. Aki nem káromkodik soha annak bravo! Én mondjuk csak akkor, ha ideges vagyok. Rengeteg részt sokszor láttam 20 év alatt. Ha bántja a kis lelked ne nézd! Neked lehet a Disney channel való!
Válasz
8/10
nikato 2020 nov. 08. - 14:17:37 8/10
A valós dolgokat igazi valójukban bemutatják, pl.: gluten mentességből divat lett, a drónok, photoshopolt képek-önértékeléssel kapcsolatos dolgok, Trónok harca, Black Friday, nemi identitás zavar, ami napjainkban őrület, vállalkozás, csóróság stb., lehetne sorolni, akik nézik tudják. Elején még a 4 fiúról szólt, a szinkron is jobb volt, aztán elkezdték ezeket a tanító jellegű, való világban zajló dolgok bemutatását. Ez a sorozat nem csak a káromkodásról szól, mert az elején még arról híresült el. Egyedül a Terrence és Phillipes reszeket nem szeretem és ami Canadáról szól.
Válasz
2/10
Gábor2003 2020 aug. 25. - 18:02:07 2/10
Ilyen 18-as rajzfilmsorozatokat biztos.nem nézek, főleg nem ezt a baromságot! Akkor se nézem ha 18 leszek!
Válasz
Kit Fisto 2018 dec. 09. - 13:28:59 Előzmény vino-et-veritas
Lehet, hogy ő is magyar volt, ki tudja.. és egyik leszármazottja a szinkronos ;)
Válasz
1/10
kinguci18k 2018 nov. 10. - 14:10:56 1/10
Az utóbbi részek és évadok már sajnos bénák,gyengék,unalmasak,gagyik,idegesítőek,felháborítóak,stb.
Persze mindíg várom a csodát,minden új résznél.
De nem jön el.
:(
Válasz
vino-et-veritas 2018 okt. 01. - 11:40:53 Előzmény Kit Fisto
Gonoszkodás.
Kolombusz is azt hitte, hogy "indiaiakkal" találkozott, amikor elérte az új kontinenst...
Válasz
Kit Fisto 2018 okt. 01. - 03:12:09
Ebben a részben Cartman egy darabig azt hiszi, hogy egy indián, Folyóvíz főnök az apja. A kiváló szinkronnak hála, mégis kétszer is indiainak mondja nagát, miközben be van öltözve indiánnak! Az angolban ugyanúgy mondják mindkettőt, és erre egy kis sütnivalóval rájöhetett volna a szinkron is.. XD
Válasz
10/10
wrtsnyrdck 2018 márc. 04. - 17:39:59 10/10
Tökéletesen tükrözi a mai társadalmat minden idõben, a régebbi évadok is nagyon aktuálisak. Egyszerûen imádom!
Válasz
Kit Fisto 2017 szept. 30. - 14:00:10
A Family Guy még betegebb, és a Brickleberry még annál is. Az már annyira, hogy nekem nézhetetlen. Abban nem hogy beteg dolgok vannak, más nincs is.
Válasz
vino-et-veritas 2017 aug. 06. - 20:47:37
Ebben a "trágárság" nem cél, hanem csak az egyik eszköz.
Amúgy pont arról is szól, hogy ne dugjuk már a homokba a fejünket, attól, hogy nem "illik" valamirõl beszélni ("nem PC"), az attól még létezik a fejekben - a rasszizmustól, az erõszakon és a fogyatékosság gúnyolásán át a "csúnyabeszédig".
A HTF megint más mûfaj, egyféle rajzfilmesített Végsõ állomás-sorozat...
Válasz
Ljerk 2017 aug. 06. - 13:18:56
Jól látod - ez valójában trágár hangnemben elõadott szatirikus, odamondogatós történetek, részenként más-más témát, viselkedést megcélozva - minimalista rajzfilm formájában. Azaz a South Parkot nem érdemes sem a vígjáték, sem a rajzfilm kategóriába tenni - pláne azok ismérvei alapján minõsíteni.
Válasz
Összes hozzászólás

## Értékelés:

1450 szavazatból
Szerinted?

1857 hozzászólás

Vetítések:
0:25, csütörtök (február 09.)
Comedy Central

# Mozi lista

- Budapest Kertmozi - Városmajor - Virág Benedek Ház
- Buda Bed Cinema - Ágymozi
- Autósmozi - Fővárosi Autópiac Budapest
- Westend Drive-In Cinema Autósmozi
- Cinema City Allee
- Cinema City Aréna
- Müpa Autósmozi
- Újpesti autósmozi
- Cinema City Campona
- Kino Cafe mozi

Kedvenc mozik szerkesztése »

# PORT.hu a Facebookon

##### Figyelmeztetés

Az értesítések jelenleg le vannak tiltva! Amennyiben szeretnél cikkajánlókat kapni, kérlek, hogy a böngésző Beállítások / Értesítések menüpontja alatt állítsd be az értesítések engedélyezését!

## Bejelentkezés

Jelentkezz be!

Belépek Facebookkal
VAGY
Hibás email cím vagy jelszó!
Elfelejtettem a jelszavam
Maradjak belépve
Regisztrálok»